@@ -1067,7 +1067,29 @@ class TelCdrInfo(AbstractModel):
         :type RecordURL: str
         :param SeatUser: 坐席信息
         :type SeatUser: :class:`tencentcloud.ccc.v20200210.models.SeatUserInfo`
-        :param EndStatus: 结束状态 0 未知 1 正常通话 2 未接通
+        :param EndStatus: 结束状态
+0	错误
+1	正常结束
+2	未接通
+17	坐席未接
+100	黑名单
+101	坐席转接
+102	IVR 期间用户放弃
+103	会话排队期间用户放弃
+104	会话振铃期间用户放弃
+105	无坐席在线
+106	非工作时间
+107	IVR后直接结束
+201	未知状态
+202	未接听
+203	拒接挂断
+204	关机
+205	空号
+206	通话中
+207	欠费
+208	运营商线路异常
+209	主叫取消
+210	不在服务区
         :type EndStatus: int
         :param SkillGroup: 技能组名称
         :type SkillGroup: str
@@ -1097,14 +1119,28 @@ class TelCdrInfo(AbstractModel):
         :param SkillGroupId: 技能组ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type SkillGroupId: int
-        :param EndStatusString: ok 正常结束 
-unconnected	未接通
-seatGiveUp	坐席未接
-seatForward	坐席转接
-ivrGiveUp	IVR期间用户放弃
-waitingGiveUp	会话排队期间用户放弃
-ringingGiveUp	会话振铃期间用户放弃
-error	系统错误
+        :param EndStatusString: error                   错误
+ok                       正常结束
+unconnected      未接通
+seatGiveUp         坐席未接
+blackList             黑名单
+seatForward       坐席转接
+ivrGiveUp           IVR 期间用户放弃
+waitingGiveUp   会话排队期间用户放弃
+ringingGiveUp   会话振铃期间用户放弃
+noSeatOnline     无坐席在线
+notWorkTime     非工作时间
+ivrEnd                 IVR后直接结束
+unknown            未知状态
+notAnswer          未接听
+userReject          拒接挂断
+powerOff            关机
+numberNotExist  空号
+busy                    通话中
+outOfCredit        欠费
+operatorError     运营商线路异常
+callerCancel        主叫取消
+notInService       不在服务区
 注意：此字段可能返回 null，表示取不到有效值。
         :type EndStatusString: str
         :param StartTimestamp: 会话开始时间戳，UNIX 秒级时间戳
