@@ -825,6 +825,31 @@ class DetectInfoVideoData(AbstractModel):
         self.LivenessVideo = params.get("LivenessVideo")
 
 
+class Encryption(AbstractModel):
+    """敏感数据加密
+
+    """
+
+    def __init__(self):
+        """
+        :param CiphertextBlob: 有加密需求的用户，接入传入kms的CiphertextBlob，关于数据加密可查阅<a href="https://cloud.tencent.com/document/product/1007/47180">数据加密</a> 文档。
+        :type CiphertextBlob: str
+        :param EncryptList: 在使用加密服务时，填入要被加密的字段。本接口中可填入加密后的一个或多个字段
+        :type EncryptList: list of str
+        :param Iv: 有加密需求的用户，传入CBC加密的初始向量
+        :type Iv: str
+        """
+        self.CiphertextBlob = None
+        self.EncryptList = None
+        self.Iv = None
+
+
+    def _deserialize(self, params):
+        self.CiphertextBlob = params.get("CiphertextBlob")
+        self.EncryptList = params.get("EncryptList")
+        self.Iv = params.get("Iv")
+
+
 class GetActionSequenceRequest(AbstractModel):
     """GetActionSequence请求参数结构体
 
@@ -874,11 +899,11 @@ class GetDetectInfoEnhancedRequest(AbstractModel):
         :type BizToken: str
         :param RuleId: 用于细分客户使用场景，由腾讯侧在线下对接时分配。
         :type RuleId: str
-        :param InfoType: 指定拉取的结果信息，取值（0：全部；1：文本类；2：身份证信息；3：视频最佳截图信息；4：视频信息）。
-如 134表示拉取文本类、视频最佳截图信息、视频信息。
+        :param InfoType: 指定拉取的结果信息，取值（0：全部；1：文本类；2：身份证信息；3：视频最佳截图信息）。
+如 13表示拉取文本类、视频最佳截图信息。
 默认值：0
         :type InfoType: str
-        :param BestFramesCount: 从活体视频中截取一定张数的最佳帧。默认为0，最大为10，超出10的最多只给10张。（InfoType需要包含3）
+        :param BestFramesCount: 从活体视频中截取一定张数的最佳帧（仅部分服务支持，若需使用请与慧眼小助手沟通）。默认为0，最大为10，超出10的最多只给10张。（InfoType需要包含3）
         :type BestFramesCount: int
         :param IsCutIdCardImage: 是否对身份证照片进行裁边。默认为false。（InfoType需要包含2）
         :type IsCutIdCardImage: bool
@@ -1263,7 +1288,7 @@ class GetRealNameAuthTokenRequest(AbstractModel):
         :type Name: str
         :param IDCard: 身份证号
         :type IDCard: str
-        :param CallbackURL: 回调地址。实名认证完成后，将会重定向到这个地址通知认证发起方
+        :param CallbackURL: 回调地址。实名认证完成后，将会重定向到这个地址通知认证发起方。仅支持http或https协议。
         :type CallbackURL: str
         """
         self.Name = None
@@ -1286,7 +1311,7 @@ class GetRealNameAuthTokenResponse(AbstractModel):
         """
         :param AuthToken: 查询实名认证结果的唯一凭证
         :type AuthToken: str
-        :param RedirectURL: 实名认证授权地址，认证发起方需要重定向到这个地址获取认证用户的授权
+        :param RedirectURL: 实名认证授权地址，认证发起方需要重定向到这个地址获取认证用户的授权，仅能在微信环境下打开。
         :type RedirectURL: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -1768,11 +1793,14 @@ class MinorsVerificationRequest(AbstractModel):
         :type IdCard: str
         :param Name: 姓名。
         :type Name: str
+        :param Encryption: 敏感数据加密信息。对传入信息（姓名、身份证号、手机号）有加密需求的用户可使用此参数，详情请点击左侧链接。
+        :type Encryption: :class:`tencentcloud.faceid.v20180301.models.Encryption`
         """
         self.Type = None
         self.Mobile = None
         self.IdCard = None
         self.Name = None
+        self.Encryption = None
 
 
     def _deserialize(self, params):
@@ -1780,6 +1808,9 @@ class MinorsVerificationRequest(AbstractModel):
         self.Mobile = params.get("Mobile")
         self.IdCard = params.get("IdCard")
         self.Name = params.get("Name")
+        if params.get("Encryption") is not None:
+            self.Encryption = Encryption()
+            self.Encryption._deserialize(params.get("Encryption"))
 
 
 class MinorsVerificationResponse(AbstractModel):
